@@ -1,6 +1,6 @@
 # vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
 
-# Copyright 2014-2020 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# Copyright 2014-2021 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
 # This file is part of qutebrowser.
 #
@@ -15,7 +15,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <http://www.gnu.org/licenses/>.
+# along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
 
 """The commandline in the statusbar."""
 
@@ -71,10 +71,8 @@ class Command(misc.MinimalLineEditMixin, misc.CommandLineEdit):
             self.history.changed.connect(command_history.changed)
         self.setSizePolicy(QSizePolicy.MinimumExpanding, QSizePolicy.Ignored)
 
-        self.cursorPositionChanged.connect(
-            self.update_completion)  # type: ignore[arg-type]
-        self.textChanged.connect(
-            self.update_completion)  # type: ignore[arg-type]
+        self.cursorPositionChanged.connect(self.update_completion)
+        self.textChanged.connect(self.update_completion)
         self.textChanged.connect(self.updateGeometry)
         self.textChanged.connect(self._incremental_search)
 
@@ -149,7 +147,7 @@ class Command(misc.MinimalLineEditMixin, misc.CommandLineEdit):
             raise cmdutils.CommandError(
                 "Invalid command text '{}'.".format(text))
         if run_on_count and count is not None:
-            self.got_cmd[str, int].emit(text, count)  # type: ignore[index]
+            self.got_cmd[str, int].emit(text, count)
         else:
             self.set_cmd_text(text)
 
@@ -189,17 +187,18 @@ class Command(misc.MinimalLineEditMixin, misc.CommandLineEdit):
         Args:
             rapid: Run the command without closing or clearing the command bar.
         """
-        text = self.text()
-        self.history.append(text)
-
         was_search = self._handle_search()
 
+        text = self.text()
+        if not (self.prefix() == ':' and text[1:].startswith(' ')):
+            self.history.append(text)
+
         if not rapid:
             modeman.leave(self._win_id, usertypes.KeyMode.command,
                           'cmd accept')
 
         if not was_search:
-            self.got_cmd[str].emit(text[1:])  # type: ignore[index]
+            self.got_cmd[str].emit(text[1:])
 
     @cmdutils.register(instance='status-command', scope='window')
     def edit_command(self, run: bool = False) -> None:
