@@ -1,6 +1,6 @@
 # vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
 
-# Copyright 2014-2017 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# Copyright 2014-2021 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
 # This file is part of qutebrowser.
 #
@@ -15,7 +15,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with qutebrowser.  If not, see <http://www.gnu.org/licenses/>.
+# along with qutebrowser.  If not, see <https://www.gnu.org/licenses/>.
 
 """Exception classes for commands modules.
 
@@ -23,38 +23,25 @@ Defined here to avoid circular dependency hell.
 """
 
 
-class CommandError(Exception):
+class Error(Exception):
 
-    """Raised when a command encounters an error while running."""
-
-    pass
+    """Base class for all cmdexc errors."""
 
 
-class CommandMetaError(Exception):
+class NoSuchCommandError(Error):
 
-    """Common base class for exceptions occurring before a command is run."""
+    """Raised when a command isn't found."""
 
 
-class NoSuchCommandError(CommandMetaError):
+class ArgumentTypeError(Error):
 
-    """Raised when a command wasn't found."""
-
-    pass
+    """Raised when an argument is an invalid type."""
 
 
-class ArgumentTypeError(CommandMetaError):
-
-    """Raised when an argument had an invalid type."""
-
-    pass
-
-
-class PrerequisitesError(CommandMetaError):
+class PrerequisitesError(Error):
 
     """Raised when a cmd can't be used because some prerequisites aren't met.
 
     This is raised for example when we're in the wrong mode while executing the
-    command, or we need javascript enabled but don't have done so.
+    command, or we need javascript enabled but haven't done so.
     """
-
-    pass
