@@ -109,6 +109,8 @@ class ValidValues:
         values: A list with the allowed untransformed values.
         descriptions: A dict with value/desc mappings.
         generate_docs: Whether to show the values in the docs.
+        others_permitted: Whether arbitrary values are permitted.
+                          Used to show buttons in qute://settings.
     """
 
     def __init__(
@@ -119,12 +121,14 @@ class ValidValues:
                 Tuple[str, Optional[str]],
             ],
             generate_docs: bool = True,
+            others_permitted: bool = False
     ) -> None:
         if not values:
             raise ValueError("ValidValues with no values makes no sense!")
         self.descriptions: DictType[str, str] = {}
         self.values: ListType[str] = []
         self.generate_docs = generate_docs
+        self.others_permitted = others_permitted
         for value in values:
             if isinstance(value, str):
                 # Value without description
@@ -1638,7 +1642,9 @@ class Proxy(BaseType):
         super().__init__(none_ok=none_ok, completions=completions)
         self.valid_values = ValidValues(
             ('system', "Use the system wide proxy."),
-            ('none', "Don't use any proxy"))
+            ('none', "Don't use any proxy"),
+            others_permitted=True,
+        )
 
     def to_py(
             self,
