@@ -479,14 +479,11 @@ class SqlTable(QObject):
         Args:
             field: Field to use as the key.
             value: Key value to delete.
-
-        Return:
-            The number of rows deleted.
         """
         q = self.database.query(f"DELETE FROM {self._name} where {field} = :val")
         q.run(val=value)
         if not q.rows_affected():
-            raise KeyError('No row with {field} = "{value}"')
+            raise KeyError(f'No row with {field} = "{value}"')
         self.changed.emit()
 
     def _insert_query(self, values: Mapping[str, Any], replace: bool) -> Query:
